@@ -2,6 +2,7 @@
 function(object,...) {
     if (!inherits(object, "randomLCA"))
         stop("Use only with 'randomLCA' objects.\n")
-     return(object$fitted)
+    fitted <- data.frame(object$patterns,Freq=object$freq,fitted=object$fitted)
+    fitted
  }
 
